"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCfSystemChoices = getCfSystemChoices;
exports.fetchBTPDestinations = fetchBTPDestinations;
const btp_utils_1 = require("@sap-ux/btp-utils");
const logger_helper_1 = __importDefault(require("../logger-helper"));
const i18n_1 = require("../i18n");
/**
 * Generates a sorted list of Cloud Foundry system destination choices from provided destinations.
 *
 * @param {Destinations} [destinations] - Object containing destination details retrieved from BTP.
 * @returns {CfSystemChoice[]} - Array of destination choices formatted for selection prompts.
 */
function createDestinationChoices(destinations = {}) {
    return Object.values(destinations)
        .filter((destination) => destination && typeof destination.Name === 'string' && typeof destination.Host === 'string')
        .sort((a, b) => a.Name.localeCompare(b.Name, undefined, { numeric: true, caseFirst: 'lower' }))
        .map((destination) => ({
        name: `${(0, btp_utils_1.getDisplayName)(destination) ?? 'Unknown'} - ${destination.Host}`,
        value: destination.Name,
        scp: (0, btp_utils_1.isAbapEnvironmentOnBtp)(destination) || false,
        url: destination.Host
    }));
}
/**
 * Retrieves an array of Cloud Foundry system choices.
 *
 * @param {Destinations} [destinations] - Optional destinations object retrieved from BTP.
 * @returns {Promise<CfSystemChoice[]>} - List of system choices formatted for selection prompts.
 */
async function getCfSystemChoices(destinations) {
    return destinations ? createDestinationChoices(destinations) : [];
}
/**
 * Retrieves and caches the list of available BTP destinations if running in BAS.
 *
 * @returns {Promise<Destinations | undefined>} - A promise resolving to a list of destinations or undefined if not in BAS.
 */
async function fetchBTPDestinations() {
    if ((0, btp_utils_1.isAppStudio)()) {
        const destinations = await (0, btp_utils_1.listDestinations)({ stripS4HCApiHosts: true });
        return destinations;
    }
    logger_helper_1.default.logger.warn((0, i18n_1.t)('warning.btpDestinationListWarning'));
    return undefined;
}
//# sourceMappingURL=prompt-helpers.js.map